from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, eq_format: enums.FileFormatDdem) -> None:
		"""SCPI: [SENSe]:DDEMod:EQUalizer:FILE:FORMat \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.equalizer.file.formatPy.set(eq_format = enums.FileFormatDdem.FRES) \n
		Determines the file format for stored equalizer results. \n
			:param eq_format: VAE | FRES VAE To be used as an equalizer file in VSA applications FRES To be used as a user-defined frequency response correction file in any other application that supports it
		"""
		param = Conversions.enum_scalar_to_str(eq_format, enums.FileFormatDdem)
		self._core.io.write(f'SENSe:DDEMod:EQUalizer:FILE:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FileFormatDdem:
		"""SCPI: [SENSe]:DDEMod:EQUalizer:FILE:FORMat \n
		Snippet: value: enums.FileFormatDdem = driver.applications.k70Vsa.sense.ddemod.equalizer.file.formatPy.get() \n
		Determines the file format for stored equalizer results. \n
			:return: eq_format: VAE | FRES VAE To be used as an equalizer file in VSA applications FRES To be used as a user-defined frequency response correction file in any other application that supports it"""
		response = self._core.io.query_str(f'SENSe:DDEMod:EQUalizer:FILE:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.FileFormatDdem)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, channel: str, state: bool) -> None:
		"""SCPI: HCOPy:PAGE:WINDow:CHANnel:STATe \n
		Snippet: driver.hardCopy.page.window.channel.state.set(channel = '1', state = False) \n
		This command selects all windows of the specified channel to be included in the printout for method RsFswp.HardCopy.
		Content.set. \n
			:param channel: String containing the name of the channel. For a list of available channel types use method RsFswp.Instrument.ListPy.get_.
			:param state: 1 | 0 | ON | OFF 1 | ON The channel windows are included in the printout. 0 | OFF The channel windows are not included in the printout.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('channel', channel, DataType.String), ArgSingle('state', state, DataType.Boolean))
		self._core.io.write(f'HCOPy:PAGE:WINDow:CHANnel:STATe {param}'.rstrip())

	# noinspection PyTypeChecker
	class StateStruct(StructBase):
		"""Response structure. Fields: \n
			- Channel: str: String containing the name of the channel. For a list of available channel types use [CMDLINK: INSTrument:LIST? CMDLINK].
			- State: bool: 1 | 0 | ON | OFF 1 | ON The channel windows are included in the printout. 0 | OFF The channel windows are not included in the printout."""
		__meta_args_list = [
			ArgStruct.scalar_str('Channel'),
			ArgStruct.scalar_bool('State')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Channel: str = None
			self.State: bool = None

	def get(self) -> StateStruct:
		"""SCPI: HCOPy:PAGE:WINDow:CHANnel:STATe \n
		Snippet: value: StateStruct = driver.hardCopy.page.window.channel.state.get() \n
		This command selects all windows of the specified channel to be included in the printout for method RsFswp.HardCopy.
		Content.set. \n
			:return: structure: for return value, see the help for StateStruct structure arguments."""
		return self._core.io.query_struct(f'HCOPy:PAGE:WINDow:CHANnel:STATe?', self.__class__.StateStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MtableCls:
	"""Mtable commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mtable", core, parent)

	def set(self, display_mode: enums.AutoMode, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:MTABle \n
		Snippet: driver.display.window.mtable.set(display_mode = enums.AutoMode.AUTO, window = repcap.Window.Default) \n
		This command turns the marker table on and off. \n
			:param display_mode: ON | 1 Turns on the marker table. OFF | 0 Turns off the marker table. AUTO Turns on the marker table if 3 or more markers are active.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.enum_scalar_to_str(display_mode, enums.AutoMode)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:MTABle {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.AutoMode:
		"""SCPI: DISPlay[:WINDow<n>]:MTABle \n
		Snippet: value: enums.AutoMode = driver.display.window.mtable.get(window = repcap.Window.Default) \n
		This command turns the marker table on and off. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: display_mode: ON | 1 Turns on the marker table. OFF | 0 Turns off the marker table. AUTO Turns on the marker table if 3 or more markers are active."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:MTABle?')
		return Conversions.str_to_scalar_enum(response, enums.AutoMode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DateCls:
	"""Date commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("date", core, parent)

	def set(self, date: str) -> None:
		"""SCPI: DIAGnostic:SERVice:CALibration:DATE \n
		Snippet: driver.diagnostic.service.calibration.date.set(date = '1') \n
		Defines last date and time the instrument was calibrated in ISO 8601 format. \n
			:param date: String containing calibration date of the instrument.
		"""
		param = Conversions.value_to_quoted_str(date)
		self._core.io.write(f'DIAGnostic:SERVice:CALibration:DATE {param}')

	def get(self) -> str:
		"""SCPI: DIAGnostic:SERVice:CALibration:DATE \n
		Snippet: value: str = driver.diagnostic.service.calibration.date.get() \n
		Defines last date and time the instrument was calibrated in ISO 8601 format. \n
			:return: date: No help available"""
		response = self._core.io.query_str(f'DIAGnostic:SERVice:CALibration:DATE?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:CREFerence:GUARd:STATe \n
		Snippet: driver.applications.k50Spurious.sense.creference.guard.state.set(state = False) \n
		Determines whether the specified guard interval is included in the spur search or not. If the guard interval is not
		included, the spectrum displays contain gaps at the guard intervals. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Guard interval is not included ON | 1 Guard interval is included
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:CREFerence:GUARd:STATe {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:CREFerence:GUARd:STATe \n
		Snippet: value: bool = driver.applications.k50Spurious.sense.creference.guard.state.get() \n
		Determines whether the specified guard interval is included in the spur search or not. If the guard interval is not
		included, the spectrum displays contain gaps at the guard intervals. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Guard interval is not included ON | 1 Guard interval is included"""
		response = self._core.io.query_str(f'SENSe:CREFerence:GUARd:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class YCls:
	"""Y commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("y", core, parent)

	def get(self, trace: enums.NoiseFigureResultCustom, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> float:
		"""SCPI: CALCulate<n>:DELTamarker<m>:Y \n
		Snippet: value: float = driver.applications.k30NoiseFigure.calculate.deltaMarker.y.get(trace = enums.NoiseFigureResultCustom.CPCold, window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		Queries the result at the position of the specified delta marker. \n
			:param trace: CPCold Queries calibration power (cold) results. CPHot Queries calibration power (hot) results. CYFactor Queries calibration 'y-factor' results. GAIN Queries 'gain' results. NOISe Queries 'noise figure' results. PCOLd Queries power (cold) results. PHOT Queries power (hot) results. TEMPerature Queries 'noise temperature' results. YFACtor Queries 'y-factor' results.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:return: result: Result at the position of the delta marker. The unit is variable and depends on the one you have currently set. Unit: DBM"""
		param = Conversions.enum_scalar_to_str(trace, enums.NoiseFigureResultCustom)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		response = self._core.io.query_str_with_opc(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:Y? {param}')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LoffsetCls:
	"""Loffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("loffset", core, parent)

	def set(self, peak_exc: float) -> None:
		"""SCPI: [SENSe]:DIRected:LOFFset \n
		Snippet: driver.applications.k50Spurious.sense.directed.loffset.set(peak_exc = 1.0) \n
		Defines a limit line as an offset to the detection threshold for each range. \n
			:param peak_exc: Range: 0 to 200, Unit: DB
		"""
		param = Conversions.decimal_value_to_str(peak_exc)
		self._core.io.write(f'SENSe:DIRected:LOFFset {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DIRected:LOFFset \n
		Snippet: value: float = driver.applications.k50Spurious.sense.directed.loffset.get() \n
		Defines a limit line as an offset to the detection threshold for each range. \n
			:return: peak_exc: Range: 0 to 200, Unit: DB"""
		response = self._core.io.query_str(f'SENSe:DIRected:LOFFset?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: SYSTem:CONFigure:GENerator:CONTrol:STATe \n
		Snippet: driver.applications.k30NoiseFigure.system.configure.generator.control.state.set(state = False) \n
		This command turns automatic control of an external generator on and off. The command is available with option R&S
		FSWP-B10. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SYSTem:CONFigure:GENerator:CONTrol:STATe {param}')

	def get(self) -> bool:
		"""SCPI: SYSTem:CONFigure:GENerator:CONTrol:STATe \n
		Snippet: value: bool = driver.applications.k30NoiseFigure.system.configure.generator.control.state.get() \n
		This command turns automatic control of an external generator on and off. The command is available with option R&S
		FSWP-B10. \n
			:return: state: ON | OFF | 1 | 0"""
		response = self._core.io.query_str(f'SYSTem:CONFigure:GENerator:CONTrol:STATe?')
		return Conversions.str_to_bool(response)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XCls:
	"""X commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("x", core, parent)

	def get(self, trace_type: enums.TraceTypeNumeric, window=repcap.Window.Default) -> List[float]:
		"""SCPI: TRACe<n>[:DATA]:X \n
		Snippet: value: List[float] = driver.applications.k50Spurious.trace.data.x.get(trace_type = enums.TraceTypeNumeric.TRACe1, window = repcap.Window.Default) \n
		This remote control command returns the X values only for the trace in the selected result display. Depending on the type
		of result display and the scaling of the x-axis, this can be either the pulse number or a timestamp for each detected
		pulse in the capture buffer. This command is only available for graphical displays, except for the Magnitude Capture
		display. \n
			:param trace_type: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trace')
			:return: trace_xdata: No help available"""
		param = Conversions.enum_scalar_to_str(trace_type, enums.TraceTypeNumeric)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_bin_or_ascii_float_list(f'FORMAT REAL,32;TRACe{window_cmd_val}:DATA:X? {param}')
		return response



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, item: str, arg_1: str = None) -> None:
		"""SCPI: HCOPy:TREPort:ITEM:SELect \n
		Snippet: driver.hardCopy.treport.item.select.set(item = r1, arg_1 = '1') \n
		No command help available \n
			:param item: No help available
			:param arg_1: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('item', item, DataType.RawString), ArgSingle('arg_1', arg_1, DataType.String, None, is_optional=True))
		self._core.io.write(f'HCOPy:TREPort:ITEM:SELect {param}'.rstrip())



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, limit_value: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit:MACCuracy:FDERror:MEAN:VALue \n
		Snippet: driver.applications.k70Vsa.calculate.limit.maccuracy.fdError.mean.value.set(limit_value = 1.0, window = repcap.Window.Default) \n
		This command defines the lower limit for the current, peak or mean center frequency deviation error. Note that the limits
		for the current and the peak value are always kept identical. This command is available for FSK modulation only. \n
			:param limit_value: Range: 0.0 to 1000000
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(limit_value)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit:MACCuracy:FDERror:MEAN:VALue {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit:MACCuracy:FDERror:MEAN:VALue \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.limit.maccuracy.fdError.mean.value.get(window = repcap.Window.Default) \n
		This command defines the lower limit for the current, peak or mean center frequency deviation error. Note that the limits
		for the current and the peak value are always kept identical. This command is available for FSK modulation only. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: limit_value: Range: 0.0 to 1000000"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit:MACCuracy:FDERror:MEAN:VALue?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RremoveCls:
	"""Rremove commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rremove", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:SSEarch:RREMove \n
		Snippet: driver.applications.k50Spurious.sense.ssearch.rremove.set(state = False) \n
		If enabled, residual spurs, which are generated by internal components in the R&S FSWP itself, are not included in the
		spur results. Note, however, if a residual spur coincides with a 'true' spur, the spur is also removed. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Residuals are not removed ON | 1 Residuals are removed
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:SSEarch:RREMove {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:SSEarch:RREMove \n
		Snippet: value: bool = driver.applications.k50Spurious.sense.ssearch.rremove.get() \n
		If enabled, residual spurs, which are generated by internal components in the R&S FSWP itself, are not included in the
		spur results. Note, however, if a residual spur coincides with a 'true' spur, the spur is also removed. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Residuals are not removed ON | 1 Residuals are removed"""
		response = self._core.io.query_str(f'SENSe:SSEarch:RREMove?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TablesCls:
	"""Tables commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tables", core, parent)

	def set(self, channel_name: str) -> None:
		"""SCPI: SYSTem:COMMunicate:INTernal[:COMMand]:TABLes \n
		Snippet: driver.system.communicate.internal.command.tables.set(channel_name = '1') \n
		No command help available \n
			:param channel_name: No help available
		"""
		param = Conversions.value_to_quoted_str(channel_name)
		self._core.io.write(f'SYSTem:COMMunicate:INTernal:COMMand:TABLes {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:COMMunicate:INTernal[:COMMand]:TABLes \n
		Snippet: value: str = driver.system.communicate.internal.command.tables.get() \n
		No command help available \n
			:return: channel_name: No help available"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:INTernal:COMMand:TABLes?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TitleCls:
	"""Title commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("title", core, parent)

	def set(self, title: str, line=repcap.Line.Default) -> None:
		"""SCPI: HCOPy:TREPort:ITEM:HEADer:LINE<li>:TITLe \n
		Snippet: driver.hardCopy.treport.item.header.line.title.set(title = '1', line = repcap.Line.Default) \n
		No command help available \n
			:param title: No help available
			:param line: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Line')
		"""
		param = Conversions.value_to_quoted_str(title)
		line_cmd_val = self._cmd_group.get_repcap_cmd_value(line, repcap.Line)
		self._core.io.write(f'HCOPy:TREPort:ITEM:HEADer:LINE{line_cmd_val}:TITLe {param}')

	def get(self, line=repcap.Line.Default) -> str:
		"""SCPI: HCOPy:TREPort:ITEM:HEADer:LINE<li>:TITLe \n
		Snippet: value: str = driver.hardCopy.treport.item.header.line.title.get(line = repcap.Line.Default) \n
		No command help available \n
			:param line: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Line')
			:return: title: No help available"""
		line_cmd_val = self._cmd_group.get_repcap_cmd_value(line, repcap.Line)
		response = self._core.io.query_str(f'HCOPy:TREPort:ITEM:HEADer:LINE{line_cmd_val}:TITLe?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FeedCls:
	"""Feed commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("feed", core, parent)

	def set(self, feed: str, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:FEED \n
		Snippet: driver.applications.k70Vsa.calculate.feed.set(feed = '1', window = repcap.Window.Default) \n
		Selects the signal source (and for the equalizer also the result type) for evaluation. Note that this command is
		maintained for compatibility reasons only. Use the LAYout commands for new remote control programs (see 'Working with
		windows in the display') . Only for the 'Equalizer Impulse Response' and 'Equalizer Frequency Response', as well as the
		multi-source diagrams, this command is required. \n
			:param feed: string 'XTIM:DDEM:MEAS' Measured signal 'XTIM:DDEM:REF' Reference signal 'XTIM:DDEM:ERR:VECT' Error vector 'XTIM:DDEM:ERR:MPH' Modulation errors 'XTIM:DDEM:MACC' Modulation accuracy 'XTIM:DDEM:SYMB' Symbol table 'TCAP' Capture buffer 'XTIM:DDEM:IMP' Equalizer Impulse Response 'XFR:DDEM:RAT' Equalizer Frequency Response 'XFR:DDEM:IRAT' Equalizer Channel Frequency Response Group Delay XTIM:DDEM:TCAP:ERR Spectrum of Real/Imag for capture buffer and error vector XTIM:DDEM:MEAS:ERR Spectrum of Real/Imag for measurement and error vector
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.value_to_quoted_str(feed)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:FEED {param}')

	def get(self, window=repcap.Window.Default) -> str:
		"""SCPI: CALCulate<n>:FEED \n
		Snippet: value: str = driver.applications.k70Vsa.calculate.feed.get(window = repcap.Window.Default) \n
		Selects the signal source (and for the equalizer also the result type) for evaluation. Note that this command is
		maintained for compatibility reasons only. Use the LAYout commands for new remote control programs (see 'Working with
		windows in the display') . Only for the 'Equalizer Impulse Response' and 'Equalizer Frequency Response', as well as the
		multi-source diagrams, this command is required. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: feed: string 'XTIM:DDEM:MEAS' Measured signal 'XTIM:DDEM:REF' Reference signal 'XTIM:DDEM:ERR:VECT' Error vector 'XTIM:DDEM:ERR:MPH' Modulation errors 'XTIM:DDEM:MACC' Modulation accuracy 'XTIM:DDEM:SYMB' Symbol table 'TCAP' Capture buffer 'XTIM:DDEM:IMP' Equalizer Impulse Response 'XFR:DDEM:RAT' Equalizer Frequency Response 'XFR:DDEM:IRAT' Equalizer Channel Frequency Response Group Delay XTIM:DDEM:TCAP:ERR Spectrum of Real/Imag for capture buffer and error vector XTIM:DDEM:MEAS:ERR Spectrum of Real/Imag for measurement and error vector"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:FEED?')
		return trim_str_response(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CorrectCls:
	"""Correct commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("correct", core, parent)

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:DSP:RESult:RRANge:CURRent:PATTern:CORRect \n
		Snippet: value: bool = driver.applications.k70Vsa.calculate.dsp.result.rrange.current.pattern.correct.get(window = repcap.Window.Default) \n
		Queries whether the pattern is correct or not in the current result range. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: correct: ON | OFF | 0 | 1 OFF | 0 Pattern not correct. ON | 1 Pattern correct"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DSP:RESult:RRANge:CURRent:PATTern:CORRect?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CseparatorCls:
	"""Cseparator commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cseparator", core, parent)

	def set(self, column_separator: enums.FileSeparator) -> None:
		"""SCPI: FORMat:DEXPort:CSEParator \n
		Snippet: driver.applications.k30NoiseFigure.formatPy.dexport.cseparator.set(column_separator = enums.FileSeparator.COMMa) \n
		No command help available \n
			:param column_separator: No help available
		"""
		param = Conversions.enum_scalar_to_str(column_separator, enums.FileSeparator)
		self._core.io.write(f'FORMat:DEXPort:CSEParator {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FileSeparator:
		"""SCPI: FORMat:DEXPort:CSEParator \n
		Snippet: value: enums.FileSeparator = driver.applications.k30NoiseFigure.formatPy.dexport.cseparator.get() \n
		No command help available \n
			:return: column_separator: No help available"""
		response = self._core.io.query_str(f'FORMat:DEXPort:CSEParator?')
		return Conversions.str_to_scalar_enum(response, enums.FileSeparator)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SweepCls:
	"""Sweep commands group definition. 31 total commands, 10 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sweep", core, parent)

	@property
	def points(self):
		"""points commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_points'):
			from .Points import PointsCls
			self._points = PointsCls(self._core, self._cmd_group)
		return self._points

	@property
	def scapture(self):
		"""scapture commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_scapture'):
			from .Scapture import ScaptureCls
			self._scapture = ScaptureCls(self._core, self._cmd_group)
		return self._scapture

	@property
	def time(self):
		"""time commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_time'):
			from .Time import TimeCls
			self._time = TimeCls(self._core, self._cmd_group)
		return self._time

	@property
	def egate(self):
		"""egate commands group. 8 Sub-classes, 1 commands."""
		if not hasattr(self, '_egate'):
			from .Egate import EgateCls
			self._egate = EgateCls(self._core, self._cmd_group)
		return self._egate

	@property
	def duration(self):
		"""duration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_duration'):
			from .Duration import DurationCls
			self._duration = DurationCls(self._core, self._cmd_group)
		return self._duration

	@property
	def window(self):
		"""window commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_window'):
			from .Window import WindowCls
			self._window = WindowCls(self._core, self._cmd_group)
		return self._window

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def typePy(self):
		"""typePy commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def optimize(self):
		"""optimize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_optimize'):
			from .Optimize import OptimizeCls
			self._optimize = OptimizeCls(self._core, self._cmd_group)
		return self._optimize

	@property
	def count(self):
		"""count commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	def clone(self) -> 'SweepCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SweepCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.Utilities import trim_str_response
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PassThroughCls:
	"""PassThrough commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("passThrough", core, parent)

	def set(self, dev_name: str, arg_1: bool) -> None:
		"""SCPI: [SENSe]:ROSCillator:PASSthrough \n
		Snippet: driver.sense.roscillator.passThrough.set(dev_name = '1', arg_1 = False) \n
		No command help available \n
			:param dev_name: No help available
			:param arg_1: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('dev_name', dev_name, DataType.String), ArgSingle('arg_1', arg_1, DataType.Boolean))
		self._core.io.write(f'SENSe:ROSCillator:PASSthrough {param}'.rstrip())

	def get(self) -> str:
		"""SCPI: [SENSe]:ROSCillator:PASSthrough \n
		Snippet: value: str = driver.sense.roscillator.passThrough.get() \n
		No command help available \n
			:return: dev_name: No help available"""
		response = self._core.io.query_str(f'SENSe:ROSCillator:PASSthrough?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpectrogramCls:
	"""Spectrogram commands group definition. 9 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spectrogram", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def threeDim(self):
		"""threeDim commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_threeDim'):
			from .ThreeDim import ThreeDimCls
			self._threeDim = ThreeDimCls(self._core, self._cmd_group)
		return self._threeDim

	@property
	def hdepth(self):
		"""hdepth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hdepth'):
			from .Hdepth import HdepthCls
			self._hdepth = HdepthCls(self._core, self._cmd_group)
		return self._hdepth

	@property
	def tstamp(self):
		"""tstamp commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tstamp'):
			from .Tstamp import TstampCls
			self._tstamp = TstampCls(self._core, self._cmd_group)
		return self._tstamp

	@property
	def frame(self):
		"""frame commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_frame'):
			from .Frame import FrameCls
			self._frame = FrameCls(self._core, self._cmd_group)
		return self._frame

	@property
	def continuous(self):
		"""continuous commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_continuous'):
			from .Continuous import ContinuousCls
			self._continuous = ContinuousCls(self._core, self._cmd_group)
		return self._continuous

	@property
	def clear(self):
		"""clear commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_clear'):
			from .Clear import ClearCls
			self._clear = ClearCls(self._core, self._cmd_group)
		return self._clear

	def clone(self) -> 'SpectrogramCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SpectrogramCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NcorrectionCls:
	"""Ncorrection commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ncorrection", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:POWer:NCORrection \n
		Snippet: driver.sense.power.ncorrection.set(state = False) \n
		This command turns noise cancellation on and off. If noise cancellation is on, the R&S FSWP performs a reference
		measurement to determine its inherent noise and subtracts the result from the channel power measurement result (first
		active trace only) . For more information see 'Noise Cancellation'. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:POWer:NCORrection {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:POWer:NCORrection \n
		Snippet: value: bool = driver.sense.power.ncorrection.get() \n
		This command turns noise cancellation on and off. If noise cancellation is on, the R&S FSWP performs a reference
		measurement to determine its inherent noise and subtracts the result from the channel power measurement result (first
		active trace only) . For more information see 'Noise Cancellation'. \n
			:return: state: ON | OFF | 1 | 0"""
		response = self._core.io.query_str(f'SENSe:POWer:NCORrection?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, source=repcap.Source.Default) -> None:
		"""SCPI: SOURce:VOLTage:CONTrol<1|2>:LEVel[:STATe] \n
		Snippet: driver.source.voltage.control.level.state.set(state = False, source = repcap.Source.Default) \n
		This command turns the tuning voltage source (Vtune) on and off. Note that DC power is actually supplied only if you
		additionally activate the outputs in general.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on DC power sources (method RsFswp.Applications.K30_NoiseFigure.Source.Voltage.State.set) . \n
			:param state: ON | OFF | 1 | 0
			:param source: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Control')
		"""
		param = Conversions.bool_to_str(state)
		source_cmd_val = self._cmd_group.get_repcap_cmd_value(source, repcap.Source)
		self._core.io.write(f'SOURce:VOLTage:CONTrol{source_cmd_val}:LEVel:STATe {param}')

	def get(self, source=repcap.Source.Default) -> bool:
		"""SCPI: SOURce:VOLTage:CONTrol<1|2>:LEVel[:STATe] \n
		Snippet: value: bool = driver.source.voltage.control.level.state.get(source = repcap.Source.Default) \n
		This command turns the tuning voltage source (Vtune) on and off. Note that DC power is actually supplied only if you
		additionally activate the outputs in general.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on DC power sources (method RsFswp.Applications.K30_NoiseFigure.Source.Voltage.State.set) . \n
			:param source: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Control')
			:return: state: ON | OFF | 1 | 0"""
		source_cmd_val = self._cmd_group.get_repcap_cmd_value(source, repcap.Source)
		response = self._core.io.query_str(f'SOURce:VOLTage:CONTrol{source_cmd_val}:LEVel:STATe?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ItemCls:
	"""Item commands group definition. 13 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("item", core, parent)

	@property
	def default(self):
		"""default commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_default'):
			from .Default import DefaultCls
			self._default = DefaultCls(self._core, self._cmd_group)
		return self._default

	@property
	def header(self):
		"""header commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_header'):
			from .Header import HeaderCls
			self._header = HeaderCls(self._core, self._cmd_group)
		return self._header

	@property
	def logo(self):
		"""logo commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_logo'):
			from .Logo import LogoCls
			self._logo = LogoCls(self._core, self._cmd_group)
		return self._logo

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def listPy(self):
		"""listPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	@property
	def template(self):
		"""template commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_template'):
			from .Template import TemplateCls
			self._template = TemplateCls(self._core, self._cmd_group)
		return self._template

	def clone(self) -> 'ItemCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ItemCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CoupleCls:
	"""Couple commands group definition. 21 total commands, 17 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("couple", core, parent)

	@property
	def center(self):
		"""center commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_center'):
			from .Center import CenterCls
			self._center = CenterCls(self._core, self._cmd_group)
		return self._center

	@property
	def span(self):
		"""span commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_span'):
			from .Span import SpanCls
			self._span = SpanCls(self._core, self._cmd_group)
		return self._span

	@property
	def refLevel(self):
		"""refLevel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_refLevel'):
			from .RefLevel import RefLevelCls
			self._refLevel = RefLevelCls(self._core, self._cmd_group)
		return self._refLevel

	@property
	def atten(self):
		"""atten commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_atten'):
			from .Atten import AttenCls
			self._atten = AttenCls(self._core, self._cmd_group)
		return self._atten

	@property
	def gain(self):
		"""gain commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gain'):
			from .Gain import GainCls
			self._gain = GainCls(self._core, self._cmd_group)
		return self._gain

	@property
	def presel(self):
		"""presel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_presel'):
			from .Presel import PreselCls
			self._presel = PreselCls(self._core, self._cmd_group)
		return self._presel

	@property
	def demod(self):
		"""demod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_demod'):
			from .Demod import DemodCls
			self._demod = DemodCls(self._core, self._cmd_group)
		return self._demod

	@property
	def bandwidth(self):
		"""bandwidth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def vbw(self):
		"""vbw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vbw'):
			from .Vbw import VbwCls
			self._vbw = VbwCls(self._core, self._cmd_group)
		return self._vbw

	@property
	def llines(self):
		"""llines commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_llines'):
			from .Llines import LlinesCls
			self._llines = LlinesCls(self._core, self._cmd_group)
		return self._llines

	@property
	def limit(self):
		"""limit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_limit'):
			from .Limit import LimitCls
			self._limit = LimitCls(self._core, self._cmd_group)
		return self._limit

	@property
	def acDc(self):
		"""acDc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_acDc'):
			from .AcDc import AcDcCls
			self._acDc = AcDcCls(self._core, self._cmd_group)
		return self._acDc

	@property
	def aunit(self):
		"""aunit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aunit'):
			from .Aunit import AunitCls
			self._aunit = AunitCls(self._core, self._cmd_group)
		return self._aunit

	@property
	def impedance(self):
		"""impedance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_impedance'):
			from .Impedance import ImpedanceCls
			self._impedance = ImpedanceCls(self._core, self._cmd_group)
		return self._impedance

	@property
	def abImpedance(self):
		"""abImpedance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_abImpedance'):
			from .AbImpedance import AbImpedanceCls
			self._abImpedance = AbImpedanceCls(self._core, self._cmd_group)
		return self._abImpedance

	@property
	def marker(self):
		"""marker commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import MarkerCls
			self._marker = MarkerCls(self._core, self._cmd_group)
		return self._marker

	@property
	def generator(self):
		"""generator commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_generator'):
			from .Generator import GeneratorCls
			self._generator = GeneratorCls(self._core, self._cmd_group)
		return self._generator

	def clone(self) -> 'CoupleCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CoupleCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, offset: float) -> None:
		"""SCPI: [SENSe]:FREQuency:OFFSet \n
		Snippet: driver.applications.k60Transient.sense.frequency.offset.set(offset = 1.0) \n
		This command defines a frequency offset. If this value is not 0 Hz, the application assumes that the input signal was
		frequency shifted outside the application. All results of type 'frequency' will be corrected for this shift numerically
		by the application. Note: In MSRA mode, the setting command is only available for the MSRA primary application. For MSRA
		secondary applications, only the query command is available. \n
			:param offset: Range: -1 THz to 1 THz, Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(offset)
		self._core.io.write(f'SENSe:FREQuency:OFFSet {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:FREQuency:OFFSet \n
		Snippet: value: float = driver.applications.k60Transient.sense.frequency.offset.get() \n
		This command defines a frequency offset. If this value is not 0 Hz, the application assumes that the input signal was
		frequency shifted outside the application. All results of type 'frequency' will be corrected for this shift numerically
		by the application. Note: In MSRA mode, the setting command is only available for the MSRA primary application. For MSRA
		secondary applications, only the query command is available. \n
			:return: offset: Range: -1 THz to 1 THz, Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:FREQuency:OFFSet?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AngleCls:
	"""Angle commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("angle", core, parent)

	def set(self, unit: enums.AngleUnit) -> None:
		"""SCPI: UNIT:ANGLe \n
		Snippet: driver.unit.angle.set(unit = enums.AngleUnit.DEG) \n
		This command selects the unit for angles (for PM display, <n> is irrelevant) . This command is identical to method RsFswp.
		Calculate.Unit.Angle.set \n
			:param unit: DEG | RAD
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.AngleUnit)
		self._core.io.write(f'UNIT:ANGLe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AngleUnit:
		"""SCPI: UNIT:ANGLe \n
		Snippet: value: enums.AngleUnit = driver.unit.angle.get() \n
		This command selects the unit for angles (for PM display, <n> is irrelevant) . This command is identical to method RsFswp.
		Calculate.Unit.Angle.set \n
			:return: unit: DEG | RAD"""
		response = self._core.io.query_str(f'UNIT:ANGLe?')
		return Conversions.str_to_scalar_enum(response, enums.AngleUnit)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, channel_type: enums.ChannelType) -> None:
		"""SCPI: INSTrument[:SELect] \n
		Snippet: driver.instrument.select.set(channel_type = enums.ChannelType.IqAnalyzer=IQ) \n
		This command activates a new channel with the defined channel type, or selects an existing channel with the specified
		name. Also see
			INTRO_CMD_HELP: See also \n
			- method RsFswp.Instrument.Create.New.set
			- 'Programming example: performing a sequence of measurements' \n
			:param channel_type: (enum or string) Channel type of the new channel. For a list of available channel types see method RsFswp.Instrument.ListPy.get_.
		"""
		param = Conversions.enum_ext_scalar_to_str(channel_type, enums.ChannelType)
		self._core.io.write_with_opc(f'INSTrument:SELect {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:UPPer:STATe \n
		Snippet: driver.applications.k30NoiseFigure.calculate.limit.upper.state.set(state = False, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command turns an upper limit line on and off. Before you can use the command, you have to select a limit line with
		method RsFswp.Calculate.Limit.Name.set. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:UPPer:STATe {param}')

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> bool:
		"""SCPI: CALCulate<n>:LIMit<li>:UPPer:STATe \n
		Snippet: value: bool = driver.applications.k30NoiseFigure.calculate.limit.upper.state.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command turns an upper limit line on and off. Before you can use the command, you have to select a limit line with
		method RsFswp.Calculate.Limit.Name.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:UPPer:STATe?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HighCls:
	"""High commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("high", core, parent)

	def set(self, bias_setting: float) -> None:
		"""SCPI: [SENSe]:MIXer:BIAS:HIGH \n
		Snippet: driver.sense.mixer.bias.high.set(bias_setting = 1.0) \n
		This command defines the bias current for the high (last) range. (See also 'Bias current') . This command is only
		available if the external mixer is active (see [SENSe:]MIXer<x>[:STATe]) . \n
			:param bias_setting: Unit: A
		"""
		param = Conversions.decimal_value_to_str(bias_setting)
		self._core.io.write(f'SENSe:MIXer:BIAS:HIGH {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:MIXer:BIAS:HIGH \n
		Snippet: value: float = driver.sense.mixer.bias.high.get() \n
		This command defines the bias current for the high (last) range. (See also 'Bias current') . This command is only
		available if the external mixer is active (see [SENSe:]MIXer<x>[:STATe]) . \n
			:return: bias_setting: Unit: A"""
		response = self._core.io.query_str(f'SENSe:MIXer:BIAS:HIGH?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimeCls:
	"""Time commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	def set(self, result_length: float) -> None:
		"""SCPI: [SENSe]:DDEMod:TIME \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.time.set(result_length = 1.0) \n
		The command determines the number of displayed symbols (result length) . \n
			:param result_length: numeric value Range: 10 to 64000, Unit: Sym
		"""
		param = Conversions.decimal_value_to_str(result_length)
		self._core.io.write(f'SENSe:DDEMod:TIME {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:TIME \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.time.get() \n
		The command determines the number of displayed symbols (result length) . \n
			:return: result_length: numeric value Range: 10 to 64000, Unit: Sym"""
		response = self._core.io.query_str(f'SENSe:DDEMod:TIME?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'TimeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TimeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, mapping: str) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:MAPPing[:VALue] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.mapping.value.set(mapping = '1') \n
		This command selects the mapping for pattern demodulation. This command is only available if the additional
		Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:param mapping: To obtain a list of available symbol mappings for the current modulation type use the [SENSe:]DDEMod:PATTern:MAPPing:CATalog?? query.
		"""
		param = Conversions.value_to_quoted_str(mapping)
		self._core.io.write(f'SENSe:DDEMod:PATTern:MAPPing:VALue {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:DDEMod:PATTern:MAPPing[:VALue] \n
		Snippet: value: str = driver.applications.k70Vsa.sense.ddemod.pattern.mapping.value.get() \n
		This command selects the mapping for pattern demodulation. This command is only available if the additional
		Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:return: mapping: To obtain a list of available symbol mappings for the current modulation type use the [SENSe:]DDEMod:PATTern:MAPPing:CATalog?? query."""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:MAPPing:VALue?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def set(self) -> None:
		"""SCPI: MMEMory:SELect[:ITEM]:ALL \n
		Snippet: driver.massMemory.select.item.all.set() \n
		This command includes all items when storing or loading a configuration file. Depending on the used command, either the
		items from the entire instrument (MMEMory:SELect[:ITEM]...) , or only those from the currently selected channel
		(MMEM:SELect:CHANnel[:ITEM]...) are stored or loaded. The items are:
			- Hardware configuration: method RsFswp.MassMemory.Select.Item.HwSettings.set
			- Limit lines: method RsFswp.MassMemory.Select.Item.Lines.All.set
			- Spectrogram data: MMEMory:SELect[:ITEM]:SGRam
			- Trace data: MMEMory:SELect[:ITEM]:TRACe<1...3>[:ACTive] \n
		"""
		self._core.io.write(f'MMEMory:SELect:ITEM:ALL')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: MMEMory:SELect[:ITEM]:ALL \n
		Snippet: driver.massMemory.select.item.all.set_with_opc() \n
		This command includes all items when storing or loading a configuration file. Depending on the used command, either the
		items from the entire instrument (MMEMory:SELect[:ITEM]...) , or only those from the currently selected channel
		(MMEM:SELect:CHANnel[:ITEM]...) are stored or loaded. The items are:
			- Hardware configuration: method RsFswp.MassMemory.Select.Item.HwSettings.set
			- Limit lines: method RsFswp.MassMemory.Select.Item.Lines.All.set
			- Spectrogram data: MMEMory:SELect[:ITEM]:SGRam
			- Trace data: MMEMory:SELect[:ITEM]:TRACe<1...3>[:ACTive] \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'MMEMory:SELect:ITEM:ALL', opc_timeout_ms)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TriggerCls:
	"""Trigger commands group definition. 23 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trigger", core, parent)

	@property
	def sequence(self):
		"""sequence commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_sequence'):
			from .Sequence import SequenceCls
			self._sequence = SequenceCls(self._core, self._cmd_group)
		return self._sequence

	@property
	def master(self):
		"""master commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_master'):
			from .Master import MasterCls
			self._master = MasterCls(self._core, self._cmd_group)
		return self._master

	@property
	def sender(self):
		"""sender commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sender'):
			from .Sender import SenderCls
			self._sender = SenderCls(self._core, self._cmd_group)
		return self._sender

	@property
	def iq(self):
		"""iq commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	def clone(self) -> 'TriggerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TriggerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AcquireCls:
	"""Acquire commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("acquire", core, parent)

	def set(self, meas_type: enums.CorrectionMeasType) -> None:
		"""SCPI: [SENSe]:CORRection:COLLect[:ACQuire] \n
		Snippet: driver.sense.correction.collect.acquire.set(meas_type = enums.CorrectionMeasType.OPEN) \n
		No command help available \n
			:param meas_type: No help available
		"""
		param = Conversions.enum_scalar_to_str(meas_type, enums.CorrectionMeasType)
		self._core.io.write(f'SENSe:CORRection:COLLect:ACQuire {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InitiateCls:
	"""Initiate commands group definition. 12 total commands, 6 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("initiate", core, parent)

	@property
	def spurious(self):
		"""spurious commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spurious'):
			from .Spurious import SpuriousCls
			self._spurious = SpuriousCls(self._core, self._cmd_group)
		return self._spurious

	@property
	def espectrum(self):
		"""espectrum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_espectrum'):
			from .Espectrum import EspectrumCls
			self._espectrum = EspectrumCls(self._core, self._cmd_group)
		return self._espectrum

	@property
	def sequencer(self):
		"""sequencer commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_sequencer'):
			from .Sequencer import SequencerCls
			self._sequencer = SequencerCls(self._core, self._cmd_group)
		return self._sequencer

	@property
	def block(self):
		"""block commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_block'):
			from .Block import BlockCls
			self._block = BlockCls(self._core, self._cmd_group)
		return self._block

	@property
	def conMeas(self):
		"""conMeas commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conMeas'):
			from .ConMeas import ConMeasCls
			self._conMeas = ConMeasCls(self._core, self._cmd_group)
		return self._conMeas

	@property
	def continuous(self):
		"""continuous commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_continuous'):
			from .Continuous import ContinuousCls
			self._continuous = ContinuousCls(self._core, self._cmd_group)
		return self._continuous

	def immediate(self) -> None:
		"""SCPI: INITiate[:IMMediate] \n
		Snippet: driver.initiate.immediate() \n
		This command starts a (single) new measurement. With measurement count or average count > 0, this means a restart of the
		corresponding number of measurements. With trace mode MAXHold, MINHold and AVERage, the previous results are reset on
		restarting the measurement. You can synchronize to the end of the measurement with *OPC, *OPC? or *WAI. For details on
		synchronization see Remote control via SCPI. \n
		"""
		self._core.io.write(f'INITiate:IMMediate')

	def immediate_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: INITiate[:IMMediate] \n
		Snippet: driver.initiate.immediate_with_opc() \n
		This command starts a (single) new measurement. With measurement count or average count > 0, this means a restart of the
		corresponding number of measurements. With trace mode MAXHold, MINHold and AVERage, the previous results are reset on
		restarting the measurement. You can synchronize to the end of the measurement with *OPC, *OPC? or *WAI. For details on
		synchronization see Remote control via SCPI. \n
		Same as immediate, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'INITiate:IMMediate', opc_timeout_ms)

	def clone(self) -> 'InitiateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = InitiateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PortsCls:
	"""Ports commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ports", core, parent)

	def set(self, port: float) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:PORTs \n
		Snippet: driver.applications.k50Spurious.sense.correction.cvl.ports.set(port = 1.0) \n
		This command defines the mixer type in the conversion loss table. This setting is checked against the current mixer
		setting before the table can be assigned to the range. Before this command can be performed, the conversion loss table
		must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only available with option B21 (External Mixer)
		installed. \n
			:param port: 2 | 3
		"""
		param = Conversions.decimal_value_to_str(port)
		self._core.io.write(f'SENSe:CORRection:CVL:PORTs {param}')

	def get(self, port: float) -> float:
		"""SCPI: [SENSe]:CORRection:CVL:PORTs \n
		Snippet: value: float = driver.applications.k50Spurious.sense.correction.cvl.ports.get(port = 1.0) \n
		This command defines the mixer type in the conversion loss table. This setting is checked against the current mixer
		setting before the table can be assigned to the range. Before this command can be performed, the conversion loss table
		must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only available with option B21 (External Mixer)
		installed. \n
			:param port: 2 | 3
			:return: port: No help available"""
		param = Conversions.decimal_value_to_str(port)
		response = self._core.io.query_str(f'SENSe:CORRection:CVL:PORTs? {param}')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UncertaintyCls:
	"""Uncertainty commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uncertainty", core, parent)

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:UNCertainty:SANalyzer:NOISe:UNCertainty \n
		Snippet: value: float = driver.applications.k30NoiseFigure.calculate.uncertainty.sanalyzer.noise.uncertainty.get(window = repcap.Window.Default) \n
		This command queries the uncertainty value of the spectrum analyzer's internal noise. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: uncertainty: 'Noise figure' uncertainty of the spectrum analyzer in dB. Unit: DB"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:UNCertainty:SANalyzer:NOISe:UNCertainty?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.SweepModeC) -> None:
		"""SCPI: [SENSe]:SWEep:MODE \n
		Snippet: driver.sense.sweep.mode.set(mode = enums.SweepModeC.AUTO) \n
		This command selects the configuration mode of the half decade table. \n
			:param mode: MANual Manual mode: allows you to select a custom resolution bandwidth and number of cross-correlations for each half decade. • Define the RBW for a half decade with [SENSe:]LIST:RANGeri:BWIDth[:RESolution]. • Define the number of cross-correlations for a half decade with [SENSe:]LIST:RANGeri:XCOunt. NORMal Automatic mode: the application selects the resolution bandwidth and number of cross-correlations based on the RBW and XCORR factors. • Define the RBW factor with [SENSe:]LIST:BWIDth[:RESolution]:RATio. • Define the XCORR factor with [SENSe:]SWEep:XFACtor. FAST Sets mode to NORMal and XCORR Count to 1. Only available remote. AVERaged Sets mode to NORMal and XCORR Count to 10. Only available remote.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.SweepModeC)
		self._core.io.write(f'SENSe:SWEep:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SweepModeC:
		"""SCPI: [SENSe]:SWEep:MODE \n
		Snippet: value: enums.SweepModeC = driver.sense.sweep.mode.get() \n
		This command selects the configuration mode of the half decade table. \n
			:return: mode: MANual Manual mode: allows you to select a custom resolution bandwidth and number of cross-correlations for each half decade. • Define the RBW for a half decade with [SENSe:]LIST:RANGeri:BWIDth[:RESolution]. • Define the number of cross-correlations for a half decade with [SENSe:]LIST:RANGeri:XCOunt. NORMal Automatic mode: the application selects the resolution bandwidth and number of cross-correlations based on the RBW and XCORR factors. • Define the RBW factor with [SENSe:]LIST:BWIDth[:RESolution]:RATio. • Define the XCORR factor with [SENSe:]SWEep:XFACtor. FAST Sets mode to NORMal and XCORR Count to 1. Only available remote. AVERaged Sets mode to NORMal and XCORR Count to 10. Only available remote."""
		response = self._core.io.query_str(f'SENSe:SWEep:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.SweepModeC)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CatalogCls:
	"""Catalog commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("catalog", core, parent)

	def get(self) -> float:
		"""SCPI: [SENSe]:CORRection:CVL:CATalog \n
		Snippet: value: float = driver.sense.correction.cvl.catalog.get() \n
		This command queries all available conversion loss tables saved in the C:/R_S/INSTR/USER/cvl/ directory on the instrument.
		This command is only available with option B21 (External Mixer) installed. \n
			:return: catalog: 'string' Comma-separated list of strings containing the file names."""
		response = self._core.io.query_str(f'SENSe:CORRection:CVL:CATalog?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PcountCls:
	"""Pcount commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pcount", core, parent)

	def set(self, amount: float) -> None:
		"""SCPI: [SENSe]:SWEep:EGATe:CONTinuous:PCOunt \n
		Snippet: driver.applications.k30NoiseFigure.sense.sweep.egate.continuous.pcount.set(amount = 1.0) \n
		Defines the number of gate periods to be measured after a single trigger event. \n
			:param amount: integer Range: 1 to 65535
		"""
		param = Conversions.decimal_value_to_str(amount)
		self._core.io.write(f'SENSe:SWEep:EGATe:CONTinuous:PCOunt {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:EGATe:CONTinuous:PCOunt \n
		Snippet: value: float = driver.applications.k30NoiseFigure.sense.sweep.egate.continuous.pcount.get() \n
		Defines the number of gate periods to be measured after a single trigger event. \n
			:return: amount: integer Range: 1 to 65535"""
		response = self._core.io.query_str(f'SENSe:SWEep:EGATe:CONTinuous:PCOunt?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SenseCls:
	"""Sense commands group definition. 87 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sense", core, parent)

	@property
	def probe(self):
		"""probe commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_probe'):
			from .Probe import ProbeCls
			self._probe = ProbeCls(self._core, self._cmd_group)
		return self._probe

	@property
	def correction(self):
		"""correction commands group. 6 Sub-classes, 1 commands."""
		if not hasattr(self, '_correction'):
			from .Correction import CorrectionCls
			self._correction = CorrectionCls(self._core, self._cmd_group)
		return self._correction

	@property
	def bandwidth(self):
		"""bandwidth commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def sweep(self):
		"""sweep commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def frequency(self):
		"""frequency commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def configure(self):
		"""configure commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_configure'):
			from .Configure import ConfigureCls
			self._configure = ConfigureCls(self._core, self._cmd_group)
		return self._configure

	def clone(self) -> 'SenseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SenseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IvalCls:
	"""Ival commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ival", core, parent)

	# noinspection PyTypeChecker
	class TimeSpan(StructBase):
		"""Response structure. Fields: \n
			- Start: float: No parameter help available
			- Stop: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Start'),
			ArgStruct.scalar_float('Stop')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Start: float = None
			self.Stop: float = None

	def get(self, stimulus: float, window=repcap.Window.Default) -> TimeSpan:
		"""SCPI: CALCulate<n>:MSRA:WINDow:IVAL \n
		Snippet: value: TimeSpan = driver.calculate.msra.window.ival.get(stimulus = 1.0, window = repcap.Window.Default) \n
		No command help available \n
			:param stimulus: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: structure: for return value, see the help for TimeSpan structure arguments."""
		param = Conversions.decimal_value_to_str(stimulus)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:MSRA:WINDow:IVAL? {param}', self.__class__.TimeSpan())



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SenseCls:
	"""Sense commands group definition. 460 total commands, 26 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sense", core, parent)

	@property
	def roscillator(self):
		"""roscillator commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_roscillator'):
			from .Roscillator import RoscillatorCls
			self._roscillator = RoscillatorCls(self._core, self._cmd_group)
		return self._roscillator

	@property
	def adjust(self):
		"""adjust commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_adjust'):
			from .Adjust import AdjustCls
			self._adjust = AdjustCls(self._core, self._cmd_group)
		return self._adjust

	@property
	def power(self):
		"""power commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def sweep(self):
		"""sweep commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def mixer(self):
		"""mixer commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_mixer'):
			from .Mixer import MixerCls
			self._mixer = MixerCls(self._core, self._cmd_group)
		return self._mixer

	@property
	def correction(self):
		"""correction commands group. 6 Sub-classes, 1 commands."""
		if not hasattr(self, '_correction'):
			from .Correction import CorrectionCls
			self._correction = CorrectionCls(self._core, self._cmd_group)
		return self._correction

	@property
	def rlength(self):
		"""rlength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rlength'):
			from .Rlength import RlengthCls
			self._rlength = RlengthCls(self._core, self._cmd_group)
		return self._rlength

	@property
	def rtms(self):
		"""rtms commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rtms'):
			from .Rtms import RtmsCls
			self._rtms = RtmsCls(self._core, self._cmd_group)
		return self._rtms

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	@property
	def swapIq(self):
		"""swapIq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_swapIq'):
			from .SwapIq import SwapIqCls
			self._swapIq = SwapIqCls(self._core, self._cmd_group)
		return self._swapIq

	@property
	def ademod(self):
		"""ademod commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_ademod'):
			from .Ademod import AdemodCls
			self._ademod = AdemodCls(self._core, self._cmd_group)
		return self._ademod

	@property
	def bandwidth(self):
		"""bandwidth commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def ddemod(self):
		"""ddemod commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ddemod'):
			from .Ddemod import DdemodCls
			self._ddemod = DdemodCls(self._core, self._cmd_group)
		return self._ddemod

	@property
	def filterPy(self):
		"""filterPy commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPyCls
			self._filterPy = FilterPyCls(self._core, self._cmd_group)
		return self._filterPy

	@property
	def frequency(self):
		"""frequency commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def iq(self):
		"""iq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def listPy(self):
		"""listPy commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	@property
	def espectrum(self):
		"""espectrum commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_espectrum'):
			from .Espectrum import EspectrumCls
			self._espectrum = EspectrumCls(self._core, self._cmd_group)
		return self._espectrum

	@property
	def mpower(self):
		"""mpower commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_mpower'):
			from .Mpower import MpowerCls
			self._mpower = MpowerCls(self._core, self._cmd_group)
		return self._mpower

	@property
	def pmeter(self):
		"""pmeter commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_pmeter'):
			from .Pmeter import PmeterCls
			self._pmeter = PmeterCls(self._core, self._cmd_group)
		return self._pmeter

	@property
	def probe(self):
		"""probe commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_probe'):
			from .Probe import ProbeCls
			self._probe = ProbeCls(self._core, self._cmd_group)
		return self._probe

	@property
	def sampling(self):
		"""sampling commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sampling'):
			from .Sampling import SamplingCls
			self._sampling = SamplingCls(self._core, self._cmd_group)
		return self._sampling

	@property
	def trace(self):
		"""trace commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def average(self):
		"""average commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_average'):
			from .Average import AverageCls
			self._average = AverageCls(self._core, self._cmd_group)
		return self._average

	@property
	def msra(self):
		"""msra commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_msra'):
			from .Msra import MsraCls
			self._msra = MsraCls(self._core, self._cmd_group)
		return self._msra

	@property
	def window(self):
		"""window commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_window'):
			from .Window import WindowCls
			self._window = WindowCls(self._core, self._cmd_group)
		return self._window

	def clone(self) -> 'SenseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SenseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DutCls:
	"""Dut commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dut", core, parent)

	def set(self, dut_type: enums.DutType) -> None:
		"""SCPI: [SENSe]:CONFigure:MODE:DUT \n
		Snippet: driver.applications.k30NoiseFigure.sense.configure.mode.dut.set(dut_type = enums.DutType.AMPLifier) \n
		This command selects the type of DUT you are testing. Note that you have to use [SENSe:]CONFigure:MODE:SYSTem:LO to
		select if the LO or IF are fixed. \n
			:param dut_type: AMPLifier | DDOWnconv | DOWNconv | UPConv AMPLifier Measurements on fixed frequency DUTs. DOWNconv Measurements on down-converting DUTs. UPConv Measurements on up-converting DUTs.
		"""
		param = Conversions.enum_scalar_to_str(dut_type, enums.DutType)
		self._core.io.write(f'SENSe:CONFigure:MODE:DUT {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DutType:
		"""SCPI: [SENSe]:CONFigure:MODE:DUT \n
		Snippet: value: enums.DutType = driver.applications.k30NoiseFigure.sense.configure.mode.dut.get() \n
		This command selects the type of DUT you are testing. Note that you have to use [SENSe:]CONFigure:MODE:SYSTem:LO to
		select if the LO or IF are fixed. \n
			:return: dut_type: AMPLifier | DDOWnconv | DOWNconv | UPConv AMPLifier Measurements on fixed frequency DUTs. DOWNconv Measurements on down-converting DUTs. UPConv Measurements on up-converting DUTs."""
		response = self._core.io.query_str(f'SENSe:CONFigure:MODE:DUT?')
		return Conversions.str_to_scalar_enum(response, enums.DutType)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ShutdownCls:
	"""Shutdown commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("shutdown", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: CALibration:DUE:SHUTdown \n
		Snippet: driver.calibration.due.shutdown.set(state = False) \n
		If activated, the R&S FSWP is automatically shut down after self-alignment is completed. Note that the instrument cannot
		be restarted via remote control. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CALibration:DUE:SHUTdown {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HardCopyCls:
	"""HardCopy commands group definition. 60 total commands, 15 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hardCopy", core, parent)

	@property
	def print(self):
		"""print commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_print'):
			from .Print import PrintCls
			self._print = PrintCls(self._core, self._cmd_group)
		return self._print

	@property
	def destination(self):
		"""destination commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_destination'):
			from .Destination import DestinationCls
			self._destination = DestinationCls(self._core, self._cmd_group)
		return self._destination

	@property
	def device(self):
		"""device commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_device'):
			from .Device import DeviceCls
			self._device = DeviceCls(self._core, self._cmd_group)
		return self._device

	@property
	def immediate(self):
		"""immediate commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_immediate'):
			from .Immediate import ImmediateCls
			self._immediate = ImmediateCls(self._core, self._cmd_group)
		return self._immediate

	@property
	def item(self):
		"""item commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_item'):
			from .Item import ItemCls
			self._item = ItemCls(self._core, self._cmd_group)
		return self._item

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def tdDtamp(self):
		"""tdDtamp commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tdDtamp'):
			from .TdDtamp import TdDtampCls
			self._tdDtamp = TdDtampCls(self._core, self._cmd_group)
		return self._tdDtamp

	@property
	def page(self):
		"""page commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_page'):
			from .Page import PageCls
			self._page = PageCls(self._core, self._cmd_group)
		return self._page

	@property
	def content(self):
		"""content commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_content'):
			from .Content import ContentCls
			self._content = ContentCls(self._core, self._cmd_group)
		return self._content

	@property
	def copies(self):
		"""copies commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_copies'):
			from .Copies import CopiesCls
			self._copies = CopiesCls(self._core, self._cmd_group)
		return self._copies

	@property
	def comment(self):
		"""comment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_comment'):
			from .Comment import CommentCls
			self._comment = CommentCls(self._core, self._cmd_group)
		return self._comment

	@property
	def logo(self):
		"""logo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_logo'):
			from .Logo import LogoCls
			self._logo = LogoCls(self._core, self._cmd_group)
		return self._logo

	@property
	def treport(self):
		"""treport commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_treport'):
			from .Treport import TreportCls
			self._treport = TreportCls(self._core, self._cmd_group)
		return self._treport

	@property
	def theme(self):
		"""theme commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_theme'):
			from .Theme import ThemeCls
			self._theme = ThemeCls(self._core, self._cmd_group)
		return self._theme

	@property
	def cmap(self):
		"""cmap commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_cmap'):
			from .Cmap import CmapCls
			self._cmap = CmapCls(self._core, self._cmd_group)
		return self._cmap

	def abort(self) -> None:
		"""SCPI: HCOPy:ABORt \n
		Snippet: driver.hardCopy.abort() \n
		This command aborts a running hardcopy output. \n
		"""
		self._core.io.write(f'HCOPy:ABORt')

	def abort_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: HCOPy:ABORt \n
		Snippet: driver.hardCopy.abort_with_opc() \n
		This command aborts a running hardcopy output. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'HCOPy:ABORt', opc_timeout_ms)

	def clone(self) -> 'HardCopyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HardCopyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LogoCls:
	"""Logo commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("logo", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: DISPlay:LOGO \n
		Snippet: driver.display.logo.set(state = False) \n
		Activates/deactivates the printout of the Rohde & Schwarz company logo at the top of each page. \n
			:param state: 1 | 0 | ON | OFF 1 | ON Logo is printed. 0 | OFF Logo is not printed.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'DISPlay:LOGO {param}')

	def get(self) -> bool:
		"""SCPI: DISPlay:LOGO \n
		Snippet: value: bool = driver.display.logo.get() \n
		Activates/deactivates the printout of the Rohde & Schwarz company logo at the top of each page. \n
			:return: state: 1 | 0 | ON | OFF 1 | ON Logo is printed. 0 | OFF Logo is not printed."""
		response = self._core.io.query_str(f'DISPlay:LOGO?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, display_pps: float, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:PRATe[:VALue] \n
		Snippet: driver.applications.k70Vsa.display.window.prate.value.set(display_pps = 1.0, window = repcap.Window.Default) \n
		This command determines the number of points to be displayed per symbol if manual mode is selected (see method RsFswp.
		Applications.K70_Vsa.Display.Window.Prate.Auto.set) . This command is not available for result displays based on the
		capture buffer; in this case, the displayed points per symbol are defined by the sample rate ([SENSe:]DDEMod:PRATe
		command) . \n
			:param display_pps: 1, 2, 4, 8,16 or 32 1 only the symbol time instants are displayed 2, 4, 8, 16, 32 more points are displayed than symbols
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.decimal_value_to_str(display_pps)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:PRATe:VALue {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: DISPlay[:WINDow<n>]:PRATe[:VALue] \n
		Snippet: value: float = driver.applications.k70Vsa.display.window.prate.value.get(window = repcap.Window.Default) \n
		This command determines the number of points to be displayed per symbol if manual mode is selected (see method RsFswp.
		Applications.K70_Vsa.Display.Window.Prate.Auto.set) . This command is not available for result displays based on the
		capture buffer; in this case, the displayed points per symbol are defined by the sample rate ([SENSe:]DDEMod:PRATe
		command) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: display_pps: 1, 2, 4, 8,16 or 32 1 only the symbol time instants are displayed 2, 4, 8, 16, 32 more points are displayed than symbols"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:PRATe:VALue?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AlphaCls:
	"""Alpha commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("alpha", core, parent)

	def set(self, meas_filter_alpha_bt: float) -> None:
		"""SCPI: [SENSe]:DDEMod:MFILter:ALPHa \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.mfilter.alpha.set(meas_filter_alpha_bt = 1.0) \n
		This command sets the alpha value of the measurement filter. \n
			:param meas_filter_alpha_bt: Range: 0.03 to 1.0, Unit: none
		"""
		param = Conversions.decimal_value_to_str(meas_filter_alpha_bt)
		self._core.io.write(f'SENSe:DDEMod:MFILter:ALPHa {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:MFILter:ALPHa \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.mfilter.alpha.get() \n
		This command sets the alpha value of the measurement filter. \n
			:return: meas_filter_alpha_bt: Range: 0.03 to 1.0, Unit: none"""
		response = self._core.io.query_str(f'SENSe:DDEMod:MFILter:ALPHa?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultsCls:
	"""Results commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("results", core, parent)

	@property
	def save(self):
		"""save commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_save'):
			from .Save import SaveCls
			self._save = SaveCls(self._core, self._cmd_group)
		return self._save

	def delete(self) -> None:
		"""SCPI: DIAGnostic:SERVice:SFUNction:RESults:DELete \n
		Snippet: driver.diagnostic.service.sfunction.results.delete() \n
		This command deletes the results in the output buffer for service functions you have used. \n
		"""
		self._core.io.write(f'DIAGnostic:SERVice:SFUNction:RESults:DELete')

	def delete_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: DIAGnostic:SERVice:SFUNction:RESults:DELete \n
		Snippet: driver.diagnostic.service.sfunction.results.delete_with_opc() \n
		This command deletes the results in the output buffer for service functions you have used. \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DIAGnostic:SERVice:SFUNction:RESults:DELete', opc_timeout_ms)

	def clone(self) -> 'ResultsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ResultsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DpathCls:
	"""Dpath commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dpath", core, parent)

	def set(self, direct_path_setting: enums.AutoOrOff) -> None:
		"""SCPI: INPut:DPATh \n
		Snippet: driver.inputPy.dpath.set(direct_path_setting = enums.AutoOrOff.AUTO) \n
		Enables or disables the use of the direct path for frequencies close to 0 Hz. \n
			:param direct_path_setting: No help available
		"""
		param = Conversions.enum_scalar_to_str(direct_path_setting, enums.AutoOrOff)
		self._core.io.write(f'INPut:DPATh {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AutoOrOff:
		"""SCPI: INPut:DPATh \n
		Snippet: value: enums.AutoOrOff = driver.inputPy.dpath.get() \n
		Enables or disables the use of the direct path for frequencies close to 0 Hz. \n
			:return: direct_path_setting: No help available"""
		response = self._core.io.query_str(f'INPut:DPATh?')
		return Conversions.str_to_scalar_enum(response, enums.AutoOrOff)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, dev_name: str, trigger_iq_source: enums.TriggerPort) -> None:
		"""SCPI: TRIGger:IQ:SENDer:SOURce \n
		Snippet: driver.trigger.iq.sender.source.set(dev_name = '1', trigger_iq_source = enums.TriggerPort.EXT1) \n
		No command help available \n
			:param dev_name: No help available
			:param trigger_iq_source: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('dev_name', dev_name, DataType.String), ArgSingle('trigger_iq_source', trigger_iq_source, DataType.Enum, enums.TriggerPort))
		self._core.io.write(f'TRIGger:IQ:SENDer:SOURce {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self) -> enums.TriggerPort:
		"""SCPI: TRIGger:IQ:SENDer:SOURce \n
		Snippet: value: enums.TriggerPort = driver.trigger.iq.sender.source.get() \n
		No command help available \n
			:return: trigger_iq_source: No help available"""
		response = self._core.io.query_str(f'TRIGger:IQ:SENDer:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.TriggerPort)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PresetCls:
	"""Preset commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("preset", core, parent)

	@property
	def standard(self):
		"""standard commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_standard'):
			from .Standard import StandardCls
			self._standard = StandardCls(self._core, self._cmd_group)
		return self._standard

	@property
	def store(self):
		"""store commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_store'):
			from .Store import StoreCls
			self._store = StoreCls(self._core, self._cmd_group)
		return self._store

	@property
	def restore(self):
		"""restore commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_restore'):
			from .Restore import RestoreCls
			self._restore = RestoreCls(self._core, self._cmd_group)
		return self._restore

	def clone(self) -> 'PresetCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PresetCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CatalogCls:
	"""Catalog commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("catalog", core, parent)

	def get(self, touchStone=repcap.TouchStone.Default) -> str:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:SLISt<sli>:CATalog \n
		Snippet: value: str = driver.sense.correction.fresponse.user.slist.catalog.get(touchStone = repcap.TouchStone.Default) \n
		No command help available \n
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
			:return: file_list: No help available"""
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		response = self._core.io.query_str(f'SENSe:CORRection:FRESponse:USER:SLISt{touchStone_cmd_val}:CATalog?')
		return trim_str_response(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PreampCls:
	"""Preamp commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("preamp", core, parent)

	def set(self, option: enums.PreampOption) -> None:
		"""SCPI: SYSTem:PREamp \n
		Snippet: driver.system.preamp.set(option = enums.PreampOption.B23) \n
		No command help available \n
			:param option: No help available
		"""
		param = Conversions.enum_scalar_to_str(option, enums.PreampOption)
		self._core.io.write(f'SYSTem:PREamp {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PreampOption:
		"""SCPI: SYSTem:PREamp \n
		Snippet: value: enums.PreampOption = driver.system.preamp.get() \n
		No command help available \n
			:return: option: No help available"""
		response = self._core.io.query_str(f'SYSTem:PREamp?')
		return Conversions.str_to_scalar_enum(response, enums.PreampOption)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, fileList=repcap.FileList.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:BASeband:USER:FLISt<fli>:PHASe[:STATe] \n
		Snippet: driver.sense.correction.fresponse.baseband.user.flist.phase.state.set(state = False, fileList = repcap.FileList.Default) \n
		No command help available \n
			:param state: No help available
			:param fileList: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
		"""
		param = Conversions.bool_to_str(state)
		fileList_cmd_val = self._cmd_group.get_repcap_cmd_value(fileList, repcap.FileList)
		self._core.io.write(f'SENSe:CORRection:FRESponse:BASeband:USER:FLISt{fileList_cmd_val}:PHASe:STATe {param}')

	def get(self, fileList=repcap.FileList.Default) -> bool:
		"""SCPI: [SENSe]:CORRection:FRESponse:BASeband:USER:FLISt<fli>:PHASe[:STATe] \n
		Snippet: value: bool = driver.sense.correction.fresponse.baseband.user.flist.phase.state.get(fileList = repcap.FileList.Default) \n
		No command help available \n
			:param fileList: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
			:return: state: No help available"""
		fileList_cmd_val = self._cmd_group.get_repcap_cmd_value(fileList, repcap.FileList)
		response = self._core.io.query_str(f'SENSe:CORRection:FRESponse:BASeband:USER:FLISt{fileList_cmd_val}:PHASe:STATe?')
		return Conversions.str_to_bool(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self) -> str:
		"""SCPI: CALibration:RESult \n
		Snippet: value: str = driver.calibration.result.get() \n
		This command returns the results collected during calibration. \n
			:return: calibration_data: String containing the calibration data."""
		response = self._core.io.query_str(f'CALibration:RESult?')
		return trim_str_response(response)



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, freq: List[float], level: List[float]) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:DATA \n
		Snippet: driver.sense.correction.cvl.data.set(freq = [1.1, 2.2, 3.3], level = [1.1, 2.2, 3.3]) \n
		This command defines the reference values of the selected conversion loss tables. The values are entered as a set of
		frequency/level pairs. A maximum of 50 frequency/level pairs may be entered. Before this command can be performed, the
		conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only available with option
		B21 (External Mixer) installed. \n
			:param freq: The frequencies have to be sent in ascending order. Unit: HZ
			:param level: Unit: DB
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('freq', freq, DataType.FloatList, None), ArgSingle.as_open_list('level', level, DataType.FloatList, None))
		self._core.io.write(f'SENSe:CORRection:CVL:DATA {param}'.rstrip())

	# noinspection PyTypeChecker
	class DataStruct(StructBase):
		"""Response structure. Fields: \n
			- Freq: List[float]: The frequencies have to be sent in ascending order. Unit: HZ
			- Level: List[float]: Unit: DB"""
		__meta_args_list = [
			ArgStruct('Freq', DataType.FloatList, None, False, True, 1),
			ArgStruct('Level', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Freq: List[float] = None
			self.Level: List[float] = None

	def get(self) -> DataStruct:
		"""SCPI: [SENSe]:CORRection:CVL:DATA \n
		Snippet: value: DataStruct = driver.sense.correction.cvl.data.get() \n
		This command defines the reference values of the selected conversion loss tables. The values are entered as a set of
		frequency/level pairs. A maximum of 50 frequency/level pairs may be entered. Before this command can be performed, the
		conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only available with option
		B21 (External Mixer) installed. \n
			:return: structure: for return value, see the help for DataStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:CORRection:CVL:DATA?', self.__class__.DataStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UserCls:
	"""User commands group definition. 24 total commands, 6 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("user", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def adjust(self):
		"""adjust commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adjust'):
			from .Adjust import AdjustCls
			self._adjust = AdjustCls(self._core, self._cmd_group)
		return self._adjust

	@property
	def refresh(self):
		"""refresh commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_refresh'):
			from .Refresh import RefreshCls
			self._refresh = RefreshCls(self._core, self._cmd_group)
		return self._refresh

	@property
	def store(self):
		"""store commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_store'):
			from .Store import StoreCls
			self._store = StoreCls(self._core, self._cmd_group)
		return self._store

	@property
	def flist(self):
		"""flist commands group. 7 Sub-classes, 1 commands."""
		if not hasattr(self, '_flist'):
			from .Flist import FlistCls
			self._flist = FlistCls(self._core, self._cmd_group)
		return self._flist

	@property
	def slist(self):
		"""slist commands group. 7 Sub-classes, 2 commands."""
		if not hasattr(self, '_slist'):
			from .Slist import SlistCls
			self._slist = SlistCls(self._core, self._cmd_group)
		return self._slist

	def preset(self, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:PRESet \n
		Snippet: driver.sense.correction.fresponse.inputPy.user.preset(inputIx = repcap.InputIx.Default) \n
		No command help available \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:PRESet')

	def preset_with_opc(self, inputIx=repcap.InputIx.Default, opc_timeout_ms: int = -1) -> None:
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:PRESet \n
		Snippet: driver.sense.correction.fresponse.inputPy.user.preset_with_opc(inputIx = repcap.InputIx.Default) \n
		No command help available \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:PRESet', opc_timeout_ms)

	def load(self, file_path: str, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:LOAD \n
		Snippet: driver.sense.correction.fresponse.inputPy.user.load(file_path = '1', inputIx = repcap.InputIx.Default) \n
		No command help available \n
			:param file_path: No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.value_to_quoted_str(file_path)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:LOAD {param}')

	def clone(self) -> 'UserCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UserCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPyCls:
	"""ListPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	def get(self) -> List[str]:
		"""SCPI: [SENSe]:CORRection:LOSS:CALibration:TABLe:LIST \n
		Snippet: value: List[str] = driver.applications.k30NoiseFigure.sense.correction.loss.calibration.table.listPy.get() \n
		This command queries all calibration loss tables available in the application. \n
			:return: result: No help available"""
		response = self._core.io.query_str(f'SENSe:CORRection:LOSS:CALibration:TABLe:LIST?')
		return Conversions.str_to_str_list(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Types import DataType
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UpperCls:
	"""Upper commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("upper", core, parent)

	def set(self, sb_gaps: enums.SubBlockGaps, state: bool, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:FILTer[:STATe]:GAP<gap>:MANual:UPPer \n
		Snippet: driver.sense.power.achannel.filterPy.state.gap.manual.upper.set(sb_gaps = enums.SubBlockGaps.AB, state = False, gapChannel = repcap.GapChannel.Default) \n
		No command help available \n
			:param sb_gaps: No help available
			:param state: No help available
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('sb_gaps', sb_gaps, DataType.Enum, enums.SubBlockGaps), ArgSingle('state', state, DataType.Boolean))
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'SENSe:POWer:ACHannel:FILTer:STATe:GAP{gapChannel_cmd_val}:MANual:UPPer {param}'.rstrip())

	def get(self, sb_gaps: enums.SubBlockGaps, gapChannel=repcap.GapChannel.Default) -> bool:
		"""SCPI: [SENSe]:POWer:ACHannel:FILTer[:STATe]:GAP<gap>:MANual:UPPer \n
		Snippet: value: bool = driver.sense.power.achannel.filterPy.state.gap.manual.upper.get(sb_gaps = enums.SubBlockGaps.AB, gapChannel = repcap.GapChannel.Default) \n
		No command help available \n
			:param sb_gaps: No help available
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: state: No help available"""
		param = Conversions.enum_scalar_to_str(sb_gaps, enums.SubBlockGaps)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:FILTer:STATe:GAP{gapChannel_cmd_val}:MANual:UPPer? {param}')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CatalogCls:
	"""Catalog commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("catalog", core, parent)

	def set(self, patterns: enums.SelectionRangeB) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:CATalog \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.sync.catalog.set(patterns = enums.SelectionRangeB.ALL) \n
		This command reads the names of all patterns stored on the hard disk. The file names are returned as a comma-separated
		list of strings, one for each file name (without the file extension) . \n
			:param patterns: CURRent | ALL CURRent Only patterns that belong to the current standard ALL All patterns
		"""
		param = Conversions.enum_scalar_to_str(patterns, enums.SelectionRangeB)
		self._core.io.write(f'SENSe:DDEMod:SEARch:SYNC:CATalog {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SelectionRangeB:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:CATalog \n
		Snippet: value: enums.SelectionRangeB = driver.applications.k70Vsa.sense.ddemod.search.sync.catalog.get() \n
		This command reads the names of all patterns stored on the hard disk. The file names are returned as a comma-separated
		list of strings, one for each file name (without the file extension) . \n
			:return: patterns: CURRent | ALL CURRent Only patterns that belong to the current standard ALL All patterns"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:SYNC:CATalog?')
		return Conversions.str_to_scalar_enum(response, enums.SelectionRangeB)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PtransitionCls:
	"""Ptransition commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ptransition", core, parent)

	def set(self, summary_bit: int, channel_name: str = None) -> None:
		"""SCPI: STATus:QUEStionable:TIME:PTRansition \n
		Snippet: driver.status.questionable.time.ptransition.set(summary_bit = 1, channel_name = '1') \n
		These commands control the Positive TRansition part of a register. Setting a bit causes a 0 to 1 transition in the
		corresponding bit of the associated register. The transition also writes a 1 into the associated bit of the corresponding
		EVENt register. \n
			:param summary_bit: No help available
			:param channel_name: String containing the name of the channel. The parameter is optional. If you omit it, the command works for the currently active channel.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('summary_bit', summary_bit, DataType.Integer), ArgSingle('channel_name', channel_name, DataType.String, None, is_optional=True))
		self._core.io.write(f'STATus:QUEStionable:TIME:PTRansition {param}'.rstrip())

	# noinspection PyTypeChecker
	class PtransitionStruct(StructBase):
		"""Response structure. Fields: \n
			- Summary_Bit: int: No parameter help available
			- Channel_Name: str: String containing the name of the channel. The parameter is optional. If you omit it, the command works for the currently active channel."""
		__meta_args_list = [
			ArgStruct.scalar_int('Summary_Bit'),
			ArgStruct.scalar_str('Channel_Name')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Summary_Bit: int = None
			self.Channel_Name: str = None

	def get(self) -> PtransitionStruct:
		"""SCPI: STATus:QUEStionable:TIME:PTRansition \n
		Snippet: value: PtransitionStruct = driver.status.questionable.time.ptransition.get() \n
		These commands control the Positive TRansition part of a register. Setting a bit causes a 0 to 1 transition in the
		corresponding bit of the associated register. The transition also writes a 1 into the associated bit of the corresponding
		EVENt register. \n
			:return: structure: for return value, see the help for PtransitionStruct structure arguments."""
		return self._core.io.query_struct(f'STATus:QUEStionable:TIME:PTRansition?', self.__class__.PtransitionStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	@property
	def current(self):
		"""current commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_current'):
			from .Current import CurrentCls
			self._current = CurrentCls(self._core, self._cmd_group)
		return self._current

	def set(self, sweep_count: float) -> None:
		"""SCPI: [SENSe]:SWEep:COUNt \n
		Snippet: driver.applications.k60Transient.sense.sweep.count.set(sweep_count = 1.0) \n
		This command defines the number of measurements that the application uses to average traces. In continuous measurement
		mode, the application calculates the moving average over the average count. In single measurement mode, the application
		stops the measurement and calculates the average after the average count has been reached. \n
			:param sweep_count: No help available
		"""
		param = Conversions.decimal_value_to_str(sweep_count)
		self._core.io.write(f'SENSe:SWEep:COUNt {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:COUNt \n
		Snippet: value: float = driver.applications.k60Transient.sense.sweep.count.get() \n
		This command defines the number of measurements that the application uses to average traces. In continuous measurement
		mode, the application calculates the moving average over the average count. In single measurement mode, the application
		stops the measurement and calculates the average after the average count has been reached. \n
			:return: sweep_count: No help available"""
		response = self._core.io.query_str(f'SENSe:SWEep:COUNt?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'CountCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CountCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, auto_auto_level: enums.AutoManualMode) -> None:
		"""SCPI: [SENSe]:ADJust:CONFigure[:LEVel]:DURation:MODE \n
		Snippet: driver.applications.k70Vsa.sense.adjust.configure.level.duration.mode.set(auto_auto_level = enums.AutoManualMode.AUTO) \n
		To determine the ideal reference level, the R&S FSWP performs a measurement on the current input data. This command
		selects the way the R&S FSWP determines the length of the measurement . \n
			:param auto_auto_level: AUTO The R&S FSWP determines the measurement length automatically according to the current input data. MANual The R&S FSWP uses the measurement length defined by [SENSe:]ADJust:CONFigure:LEVel:DURation.
		"""
		param = Conversions.enum_scalar_to_str(auto_auto_level, enums.AutoManualMode)
		self._core.io.write(f'SENSe:ADJust:CONFigure:LEVel:DURation:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AutoManualMode:
		"""SCPI: [SENSe]:ADJust:CONFigure[:LEVel]:DURation:MODE \n
		Snippet: value: enums.AutoManualMode = driver.applications.k70Vsa.sense.adjust.configure.level.duration.mode.get() \n
		To determine the ideal reference level, the R&S FSWP performs a measurement on the current input data. This command
		selects the way the R&S FSWP determines the length of the measurement . \n
			:return: auto_auto_level: No help available"""
		response = self._core.io.query_str(f'SENSe:ADJust:CONFigure:LEVel:DURation:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AddressCls:
	"""Address commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("address", core, parent)

	def set(self, address: float) -> None:
		"""SCPI: SYSTem:COMMunicate:GPIB[:SELF]:ADDRess \n
		Snippet: driver.system.communicate.gpib.self.address.set(address = 1.0) \n
		This command sets the GPIB address of the R&S FSWP. \n
			:param address: Range: 0 to 30
		"""
		param = Conversions.decimal_value_to_str(address)
		self._core.io.write(f'SYSTem:COMMunicate:GPIB:SELF:ADDRess {param}')

	def get(self) -> float:
		"""SCPI: SYSTem:COMMunicate:GPIB[:SELF]:ADDRess \n
		Snippet: value: float = driver.system.communicate.gpib.self.address.get() \n
		This command sets the GPIB address of the R&S FSWP. \n
			:return: address: Range: 0 to 30"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:GPIB:SELF:ADDRess?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StatisticsCls:
	"""Statistics commands group definition. 11 total commands, 5 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("statistics", core, parent)

	@property
	def amplitudeProbDensity(self):
		"""amplitudeProbDensity commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_amplitudeProbDensity'):
			from .AmplitudeProbDensity import AmplitudeProbDensityCls
			self._amplitudeProbDensity = AmplitudeProbDensityCls(self._core, self._cmd_group)
		return self._amplitudeProbDensity

	@property
	def cumulativeDistribFnc(self):
		"""cumulativeDistribFnc commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_cumulativeDistribFnc'):
			from .CumulativeDistribFnc import CumulativeDistribFncCls
			self._cumulativeDistribFnc = CumulativeDistribFncCls(self._core, self._cmd_group)
		return self._cumulativeDistribFnc

	@property
	def nsamples(self):
		"""nsamples commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsamples'):
			from .Nsamples import NsamplesCls
			self._nsamples = NsamplesCls(self._core, self._cmd_group)
		return self._nsamples

	@property
	def scale(self):
		"""scale commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_scale'):
			from .Scale import ScaleCls
			self._scale = ScaleCls(self._core, self._cmd_group)
		return self._scale

	@property
	def result(self):
		"""result commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_result'):
			from .Result import ResultCls
			self._result = ResultCls(self._core, self._cmd_group)
		return self._result

	def preset(self, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:STATistics:PRESet \n
		Snippet: driver.calculate.statistics.preset(window = repcap.Window.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:STATistics:PRESet')

	def preset_with_opc(self, window=repcap.Window.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		"""SCPI: CALCulate<n>:STATistics:PRESet \n
		Snippet: driver.calculate.statistics.preset_with_opc(window = repcap.Window.Default) \n
		No command help available \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:STATistics:PRESet', opc_timeout_ms)

	def clone(self) -> 'StatisticsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = StatisticsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SnumberCls:
	"""Snumber commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("snumber", core, parent)

	def set(self, serial_no: str) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:SNUMber \n
		Snippet: driver.sense.correction.cvl.snumber.set(serial_no = '1') \n
		This command defines the serial number of the mixer for which the conversion loss table is to be used. This setting is
		checked against the current mixer setting before the table can be assigned to the range. Before this command can be
		performed, the conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only
		available with option B21 (External Mixer) installed. \n
			:param serial_no: Serial number with a maximum of 16 characters
		"""
		param = Conversions.value_to_quoted_str(serial_no)
		self._core.io.write(f'SENSe:CORRection:CVL:SNUMber {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:CORRection:CVL:SNUMber \n
		Snippet: value: str = driver.sense.correction.cvl.snumber.get() \n
		This command defines the serial number of the mixer for which the conversion loss table is to be used. This setting is
		checked against the current mixer setting before the table can be assigned to the range. Before this command can be
		performed, the conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only
		available with option B21 (External Mixer) installed. \n
			:return: serial_no: Serial number with a maximum of 16 characters"""
		response = self._core.io.query_str(f'SENSe:CORRection:CVL:SNUMber?')
		return trim_str_response(response)
